# PySFCGAL

An official wrapper around the SFCGAL library for Python in the style of Shapely.

http://www.sfcgal.org/

![sfcgal_image](docs/docs/assets/img/sfcgal.png)

## Documentation

Documentation is automatically generated and deployed from the CI: https://sfcgal.gitlab.io/pysfcgal

## Installation

See the [installation page](https://sfcgal.gitlab.io/pysfcgal/user_guide/build/) in the documentation.

## How to contribute

You are intersted in PySFCGAL and want to contribute? Please have a look at [the contributing guidelines](CONTRIBUTING.md)!

## License

PySFCGAL license is [GNU General Public License v3](LICENSE.md).

## Credits

Initial work from https://github.com/snorfalorpagus/pysfcgal/
